@@ -1,14 +1,13 @@
 package POEx::WorkerPool::Error::EnqueueError;
 BEGIN {
-  $POEx::WorkerPool::Error::EnqueueError::VERSION = '1.101610';
+  $POEx::WorkerPool::Error::EnqueueError::VERSION = '1.102740';
 }
 
 #ABSTRACT: An error class indicating problems enqueuing a job
 
 use MooseX::Declare;
 
-class POEx::WorkerPool::Error::EnqueueError extends POEx::WorkerPool::Error
-{
+class POEx::WorkerPool::Error::EnqueueError extends POEx::WorkerPool::Error {
 
 }
 
@@ -23,7 +22,7 @@ POEx::WorkerPool::Error::EnqueueError - An error class indicating problems enque
 
 =head1 VERSION
 
-version 1.101610
+version 1.102740
 
 =head1 DESCRIPTION
 
@@ -31,7 +30,7 @@ This exception is thrown when there are issues enqueuing a job for execution.
 
 =head1 AUTHOR
 
-  Nicholas R. Perez <nperez@cpan.org>
+Nicholas R. Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
