@@ -1,14 +1,13 @@
 package POEx::WorkerPool::Error::StartError;
 BEGIN {
-  $POEx::WorkerPool::Error::StartError::VERSION = '1.101610';
+  $POEx::WorkerPool::Error::StartError::VERSION = '1.102740';
 }
 
 #ABSTRACT: An error class indicating the Worker queue failed to start
 
 use MooseX::Declare;
 
-class POEx::WorkerPool::Error::StartError extends POEx::WorkerPool::Error
-{
+class POEx::WorkerPool::Error::StartError extends POEx::WorkerPool::Error {
 
 }
 
@@ -23,11 +22,11 @@ POEx::WorkerPool::Error::StartError - An error class indicating the Worker queue
 
 =head1 VERSION
 
-version 1.101610
+version 1.102740
 
 =head1 AUTHOR
 
-  Nicholas R. Perez <nperez@cpan.org>
+Nicholas R. Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
