@@ -1,14 +1,13 @@
 package POEx::WorkerPool::Worker::Guts;
 BEGIN {
-  $POEx::WorkerPool::Worker::Guts::VERSION = '1.101610';
+  $POEx::WorkerPool::Worker::Guts::VERSION = '1.102740';
 }
 
 #ABSTRACT: A generic sub process implementation for Worker
 
 use MooseX::Declare;
 
-class POEx::WorkerPool::Worker::Guts
-{
+class POEx::WorkerPool::Worker::Guts {
     with 'MooseX::CompileTime::Traits';
     with 'POEx::WorkerPool::Role::WorkerPool::Worker::Guts';
 }
@@ -24,7 +23,7 @@ POEx::WorkerPool::Worker::Guts - A generic sub process implementation for Worker
 
 =head1 VERSION
 
-version 1.101610
+version 1.102740
 
 =head1 DESCRIPTION
 
@@ -33,7 +32,7 @@ attributes please see POEx::WorkerPool::Role::WorkerPool::Worker::Guts
 
 =head1 AUTHOR
 
-  Nicholas R. Perez <nperez@cpan.org>
+Nicholas R. Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
