@@ -1,17 +1,13 @@
 use MooseX::Declare;
 
 my $STEPS = 0;
-class FailJob with POEx::WorkerPool::Role::Job
-{
-    method import(ClassName $class: Maybe[Int] :$steps)
-    {
+class FailJob with POEx::WorkerPool::Role::Job {
+    method import(ClassName $class: Maybe[Int] :$steps) {
         $STEPS = $steps if defined($steps);
     }
 
-    method init_job
-    {
-        foreach my $step (1..$STEPS)
-        {
+    method init_job {
+        foreach my $step (1..$STEPS) {
             $self->enqueue_step
             (
                 [
